@@ -1,7 +1,8 @@
-from pandas import Series
 from typing import Optional
 
-from survey.mixins.data import DataMixin
+from pandas import Series
+
+from survey.mixins.data_mixins import NumericDataMixin
 from survey.mixins.data_types.discrete_1d_mixin import Discrete1dMixin
 from survey.mixins.data_validation.count_validation_mixin import \
     CountValidationMixin
@@ -11,7 +12,7 @@ from survey.questions._abstract.question import Question
 
 class CountQuestion(
     NamedMixin,
-    DataMixin,
+    NumericDataMixin,
     CountValidationMixin,
     Discrete1dMixin,
     Question
@@ -28,6 +29,11 @@ class CountQuestion(
         :param data: Optional pandas Series of responses.
         """
         self._set_name_and_text(name, text)
+        if data is not None:
+            try:
+                data = data.astype(int)
+            except ValueError:
+                data = data.astype(float)
         self.data = data
 
     def __repr__(self):
